@@ -31,7 +31,7 @@ def get_current_version():
     :rtype: (int, int, int)
     """
     output = get_cmd_output("git describe --always")
-    tag_regex = r"(?P<major>\d+).(?P<minor>\d+).(?P<hotfix>\d+)-.*"
+    tag_regex = r"(?P<major>\d+).(?P<minor>\d+).(?P<hotfix>\d+)-?.*"
     result = re.search(tag_regex, output)
     if result is None:
         logging.warning("Warning: no tag matching the format Major.Minor.Hotfix detected")
